@@ -52,6 +52,30 @@ show_info() {
     echo -e "${BLUE}ℹ️  $1${NC}"
 }
 
+get_port_usage() {
+    local port=$1
+    if command -v lsof &>/dev/null; then
+        sudo lsof -nP -iTCP:"$port" -sTCP:LISTEN 2>/dev/null | awk 'NR>1 {print $1 " (PID " $2 ")"}'
+    elif command -v ss &>/dev/null; then
+        sudo ss -ltnp "sport = :$port" 2>/dev/null | awk 'NR>1 {print $7}'
+    elif command -v netstat &>/dev/null; then
+        sudo netstat -ltnp 2>/dev/null | awk -v port=":$port" '$4 ~ port {print $7}'
+    else
+        echo ""
+    fi
+}
+
+get_port_pids() {
+    local port=$1
+    if command -v lsof &>/dev/null; then
+        sudo lsof -t -iTCP:"$port" -sTCP:LISTEN 2>/dev/null | tr '\n' ' '
+    elif command -v fuser &>/dev/null; then
+        sudo fuser "$port"/tcp 2>/dev/null | tr '\n' ' '
+    else
+        echo ""
+    fi
+}
+
 #############################################
 # INITIAL SETUP
 #############################################
@@ -75,6 +99,7 @@ CURRENT_USER=$(whoami)
 CURRENT_DIR="$(cd "$(dirname "$0")" && pwd)"
 VENV_PATH="$HOME/.airun_venv"
 AIRUN_DIR="$HOME/.airun"
+POSTGRES_PORT="${AIRUN_POSTGRES_PORT:-5433}"
 
 #############################################
 # PHASE 1: CLEANUP & PREPARATION
@@ -308,7 +333,7 @@ CONTAINER_NAME="airun_postgres"
 show_info "기존 PostgreSQL 컨테이너 정리 중..."
 
 # Get all containers using port 5433
-EXISTING_CONTAINERS=$(sudo docker ps -a --format "{{.Names}}" --filter "publish=5433" 2>/dev/null || true)
+EXISTING_CONTAINERS=$(sudo docker ps -a --format "{{.Names}}" --filter "publish=$POSTGRES_PORT" 2>/dev/null || true)
 if [ ! -z "$EXISTING_CONTAINERS" ]; then
     for container in $EXISTING_CONTAINERS; do
         show_info "기존 컨테이너 $container 제거 중..."
@@ -321,8 +346,8 @@ fi
 for pattern in "airun" "postgres"; do
     CONTAINERS=$(sudo docker ps -a --format "{{.Names}}" | grep -i "$pattern" | grep -v "^$CONTAINER_NAME$" || true)
     for container in $CONTAINERS; do
-        if sudo docker port "$container" 2>/dev/null | grep -q "5433"; then
-            show_info "컨테이너 $container 제거 중 (포트 5433 사용)..."
+        if sudo docker port "$container" 2>/dev/null | grep -q "$POSTGRES_PORT"; then
+            show_info "컨테이너 $container 제거 중 (포트 ${POSTGRES_PORT} 사용)..."
             sudo docker stop "$container" 2>/dev/null || true
             sudo docker rm "$container" 2>/dev/null || true
         fi
@@ -359,11 +384,45 @@ if [ "$CONTAINER_EXISTS" = false ]; then
     # Create data directory if it doesn't exist
     mkdir -p "$AIRUN_DIR/pgdata"
 
+    PORT_USAGE=$(get_port_usage "$POSTGRES_PORT")
+    PORT_PIDS=$(get_port_pids "$POSTGRES_PORT")
+    if [ -n "$PORT_USAGE" ]; then
+        show_warning "호스트 포트 ${POSTGRES_PORT}이(가) 다른 프로세스에서 사용 중입니다."
+        while IFS= read -r usage_line; do
+            if [ -n "$usage_line" ]; then
+                show_info "포트 사용 프로세스: $usage_line"
+            fi
+        done <<< "$PORT_USAGE"
+        if [ -n "$PORT_PIDS" ]; then
+            show_warning "포트를 사용 중인 프로세스를 종료합니다..."
+            for pid in $PORT_PIDS; do
+                if sudo kill "$pid" 2>/dev/null; then
+                    sleep 1
+                    if sudo kill -0 "$pid" 2>/dev/null; then
+                        sudo kill -9 "$pid" 2>/dev/null || true
+                    fi
+                    if sudo kill -0 "$pid" 2>/dev/null; then
+                        show_warning "PID $pid 강제 종료 실패"
+                    else
+                        show_success "PID $pid 종료 완료"
+                    fi
+                else
+                    show_warning "PID $pid 종료 실패"
+                fi
+            done
+            sleep 2
+        fi
+
+        if [ -n "$(get_port_pids "$POSTGRES_PORT")" ]; then
+            handle_error "포트를 비울 수 없습니다. AIRUN_POSTGRES_PORT 환경 변수로 다른 포트를 지정하거나 수동으로 포트를 비운 뒤 다시 실행해주세요."
+        fi
+    fi
+
     sudo docker run --name "$CONTAINER_NAME" \
         -e POSTGRES_USER=ivs \
         -e POSTGRES_PASSWORD=1234 \
         -e POSTGRES_DB=airun \
-        -p 5433:5432 \
+        -p $POSTGRES_PORT:5432 \
         -v "$AIRUN_DIR/pgdata:/var/lib/postgresql/data" \
         --restart always \
         -d pgvector/pgvector:pg17 \
@@ -387,7 +446,7 @@ for i in {1..30}; do
         cd "$CURRENT_DIR"
         if timeout 60 node -e "
             process.env.DB_HOST = 'localhost';
-            process.env.DB_PORT = '5433';
+            process.env.DB_PORT = '$POSTGRES_PORT';
             process.env.DB_USER = 'ivs';
             process.env.DB_PASSWORD = '1234';
             process.env.DB_NAME = 'airun';
@@ -419,6 +478,46 @@ for i in {1..30}; do
     fi
 done
 
+
+
+
+# Harden pg_hba.conf (trust -> scram-sha-256) + allow only Docker bridge
+show_info "PostgreSQL 인증 정책 강화 중(trust → scram-sha-256)..."
+sudo docker exec "$CONTAINER_NAME" bash -lc '
+  set -e
+  HBA="/var/lib/postgresql/data/pg_hba.conf"
+  BAK="$HBA.bak.$(date +%F_%T)"
+  cp "$HBA" "$BAK"
+
+  # ---- 0) 비밀번호/암호화 정책 확정 ----
+  PGPASSWORD=1234 psql -h localhost -U ivs -d airun -v ON_ERROR_STOP=1 -w \
+    -c "ALTER SYSTEM SET password_encryption = '\''scram-sha-256'\'';"
+  PGPASSWORD=1234 psql -h localhost -U ivs -d airun -v ON_ERROR_STOP=1 -w \
+    -c "ALTER ROLE ivs WITH LOGIN PASSWORD '\''1234'\'';"
+
+  # ---- 1) HBA 수정: trust -> scram ----
+  sed -i \
+    -e "s/^\(\s*local\s\+all\s\+all\s\+\)\(trust\|md5\)$/\1scram-sha-256/" \
+    -e "s/^\(\s*host\s\+all\s\+all\s\+127\.0\.0\.1\/32\s\+\)\(trust\|md5\)$/\1scram-sha-256/" \
+    -e "s/^\(\s*host\s\+all\s\+all\s\+::1\/128\s\+\)\(trust\|md5\)$/\1scram-sha-256/" \
+    -e "s/^\(\s*local\s\+replication\s\+all\s\+\)\(trust\|md5\)$/\1scram-sha-256/" \
+    -e "s/^\(\s*host\s\+replication\s\+all\s\+127\.0\.0\.1\/32\s\+\)\(trust\|md5\)$/\1scram-sha-256/" \
+    -e "s/^\(\s*host\s\+replication\s\+all\s\+::1\/128\s\+\)\(trust\|md5\)$/\1scram-sha-256/" \
+    "$HBA"
+
+  # ---- 2) 변경 사항 적용 (항상 TCP + 비번 전달) ----
+  PGPASSWORD=1234 psql -h localhost -U ivs -d airun -v ON_ERROR_STOP=1 -w \
+    -c "SELECT pg_reload_conf();"
+
+  # 확인용 요약 출력
+  PGPASSWORD=1234 psql -h localhost -U ivs -d airun -X -A -F "|" -w \
+    -c "SELECT type,database,user_name,address,auth_method FROM pg_hba_file_rules;" | head -n 20
+' || handle_error "pg_hba.conf 강화 중 오류"
+
+show_success "인증 정책 강화 완료 (scram-sha-256 적용)"
+
+
+
 # Redis setup
 show_info "Redis 설정 중..."
 sudo systemctl start redis-server || sudo systemctl start redis || true
@@ -548,11 +647,24 @@ show_success "PHASE 4 완료: Python 환경 설정 완료"
 #############################################
 show_phase 5 "AI 모델 다운로드"
 
+# 실제 설치 대상 사용자 계산 (sudo로 실행되더라도 원 사용자 보존)
+RUN_USER="${SUDO_USER:-$CURRENT_USER}"
+ensure_dir_mode() {
+  local dir="$1"
+  local mode="${2:-755}"
+  sudo install -d -m "$mode" -o "$RUN_USER" -g "$RUN_USER" "$dir"
+}
+
 # Create directories
-mkdir -p "$AIRUN_DIR/models"
-mkdir -p "$AIRUN_DIR/cache"
-mkdir -p "$AIRUN_DIR/logs"
-mkdir -p "$AIRUN_DIR/queues"
+ensure_dir_mode "$AIRUN_DIR"
+ensure_dir_mode "$AIRUN_DIR/models"
+ensure_dir_mode "$AIRUN_DIR/cache"
+ensure_dir_mode "$AIRUN_DIR/logs"
+ensure_dir_mode "$AIRUN_DIR/queues"
+# mkdir -p "$AIRUN_DIR/models"
+# mkdir -p "$AIRUN_DIR/cache"
+# mkdir -p "$AIRUN_DIR/logs"
+# mkdir -p "$AIRUN_DIR/queues"
 
 # Download text embedding model
 show_info "[1/3] 텍스트 임베딩 모델 다운로드 중..."
@@ -636,7 +748,7 @@ fi
 # Update database settings
 if grep -q "^PG_HOST=" "$ENV_FILE" 2>/dev/null; then
     sed -i "s/^PG_HOST=.*/PG_HOST=localhost/" "$ENV_FILE"
-    sed -i "s/^PG_PORT=.*/PG_PORT=5433/" "$ENV_FILE"
+    sed -i "s/^PG_PORT=.*/PG_PORT=$POSTGRES_PORT/" "$ENV_FILE"
     sed -i "s/^PG_USER=.*/PG_USER=ivs/" "$ENV_FILE"
     sed -i "s/^PG_PASSWORD=.*/PG_PASSWORD=1234/" "$ENV_FILE"
     sed -i "s/^PG_DATABASE=.*/PG_DATABASE=airun/" "$ENV_FILE"
@@ -645,7 +757,7 @@ else
 
 # Database Configuration
 PG_HOST=localhost
-PG_PORT=5433
+PG_PORT=$POSTGRES_PORT
 PG_USER=ivs
 PG_PASSWORD=1234
 PG_DATABASE=airun
@@ -1059,10 +1171,10 @@ check_postgres() {
 
     if [ "$DOCKER_ACCESS" = true ]; then
         # Check connection
-        if PGPASSWORD=1234 psql -h localhost -p 5433 -U ivs -d airun -c "\l" >/dev/null 2>&1; then
-            show_success "PostgreSQL: 실행 중 (포트 5433)"
+        if PGPASSWORD=1234 psql -h localhost -p $POSTGRES_PORT -U ivs -d airun -c "\l" >/dev/null 2>&1; then
+            show_success "PostgreSQL: 실행 중 (포트 $POSTGRES_PORT)"
             # Check pgvector extension
-            if PGPASSWORD=1234 psql -h localhost -p 5433 -U ivs -d airun -c "SELECT * FROM pg_extension WHERE extname='vector';" | grep -q vector; then
+            if PGPASSWORD=1234 psql -h localhost -p $POSTGRES_PORT -U ivs -d airun -c "SELECT * FROM pg_extension WHERE extname='vector';" | grep -q vector; then
                 show_success "pgvector 확장: 활성화됨"
             else
                 show_warning "pgvector 확장: 비활성화"
@@ -1071,11 +1183,11 @@ check_postgres() {
 
             # Check if essential tables exist (schema validation)
             show_info "데이터베이스 스키마 검증..."
-            if PGPASSWORD=1234 psql -h localhost -p 5433 -U ivs -d airun -c "SELECT 1 FROM information_schema.tables WHERE table_name='users';" | grep -q "1"; then
+            if PGPASSWORD=1234 psql -h localhost -p $POSTGRES_PORT -U ivs -d airun -c "SELECT 1 FROM information_schema.tables WHERE table_name='users';" | grep -q "1"; then
                 show_success "기본 테이블: 생성됨"
 
                 # Check for embedding_status column specifically
-                if PGPASSWORD=1234 psql -h localhost -p 5433 -U ivs -d airun -c "SELECT column_name FROM information_schema.columns WHERE table_name='rag_documents' AND column_name='embedding_status';" | grep -q "embedding_status"; then
+                if PGPASSWORD=1234 psql -h localhost -p $POSTGRES_PORT -U ivs -d airun -c "SELECT column_name FROM information_schema.columns WHERE table_name='rag_documents' AND column_name='embedding_status';" | grep -q "embedding_status"; then
                     show_success "RAG 스키마: embedding_status 컬럼 확인됨"
                 else
                     show_warning "RAG 스키마: embedding_status 컬럼 없음"
@@ -1365,4 +1477,4 @@ else
     echo -e "${YELLOW}위의 문제 해결 가이드를 참조하여 수정해주세요.${NC}"
 fi
 
-echo ""
\ No newline at end of file
+echo ""
