@@ -151,11 +151,14 @@ const createQueue = (name, options = {}) => {
             ...redisConfig,
             retryStrategy: (times) => {
                 if (times > 10) {
-                    logger.error(`[${name}] Redis 재연결 최대 시도 횟수 초과`);
+                    // 최대 재시도 횟수 초과시 null 반환하여 재연결 중단
                     return null;
                 }
-                const delay = Math.min(times * 100, 3000);
-                logger.warn(`[${name}] Redis 재연결 시도 ${times}회, ${delay}ms 후 재시도`);
+                // 로그를 debugLog로 변경하여 LOG_LEVEL=INFO일 때는 출력 안됨
+                const delay = Math.min(times * 500, 3000);
+                if (times === 1) {
+                    debugLog(`[${name}] Redis 재연결 시도 중...`);
+                }
                 return delay;
             },
             reconnectOnError: (err) => {
@@ -173,9 +176,9 @@ const createQueue = (name, options = {}) => {
     // 큐 이벤트 리스너
     queue.on('error', error => {
         if (error.code === 'ECONNREFUSED') {
-            logger.warn(`[${name}] Redis 연결 거부됨. 재연결 시도 중...`);
+            debugLog(`[${name}] Redis 연결 거부됨. 재연결 시도 중...`);
         } else {
-            logger.error(`[${name}] 오류:`, error);
+            debugLog(`[${name}] 큐 오류:`, error.message);
         }
     });
 
@@ -223,25 +226,27 @@ const createQueue = (name, options = {}) => {
     // Redis 클라이언트 이벤트 처리 (Bull은 내부적으로 ioredis 사용)
     if (queue.client) {
         queue.client.on('connect', () => {
-            logger.info(`[${name}] Redis 연결됨`);
+            debugLog(`[${name}] Redis 연결됨`);
         });
 
         queue.client.on('reconnecting', (delay) => {
-            logger.warn(`[${name}] Redis 재연결 중... (${delay}ms 후)`);
+            // 재연결 로그를 debugLog로 변경
+            debugLog(`[${name}] Redis 재연결 중... (${delay}ms 후)`);
         });
 
         queue.client.on('error', (error) => {
+            // Redis 연결 오류도 debugLog로 처리 (반복적인 오류 로그 방지)
             if (error.code === 'ECONNREFUSED') {
-                logger.warn(`[${name}] Redis 서버에 연결할 수 없습니다. 서비스가 실행 중인지 확인하세요.`);
+                debugLog(`[${name}] Redis 서버에 연결할 수 없습니다.`);
             } else if (error.code === 'ENOTFOUND') {
-                logger.error(`[${name}] Redis 호스트를 찾을 수 없습니다: ${redisConfig.host}`);
+                debugLog(`[${name}] Redis 호스트를 찾을 수 없습니다: ${redisConfig.host}`);
             } else {
-                logger.error(`[${name}] Redis 클라이언트 오류:`, error.message);
+                debugLog(`[${name}] Redis 클라이언트 오류:`, error.message);
             }
         });
 
         queue.client.on('end', () => {
-            logger.warn(`[${name}] Redis 연결이 종료되었습니다`);
+            debugLog(`[${name}] Redis 연결이 종료되었습니다`);
         });
     }
 
@@ -404,6 +409,39 @@ export async function enqueueChatRequest(prompt, options = {}, handlerEndpoint)
     }
 }
 
+// 건강검진 배치 분석 요청 큐에 작업 추가
+export async function enqueueHealthBatchAnalysis(jobId, patients) {
+    try {
+        console.log(`건강검진 배치 분석 큐에 작업 추가: ${jobId}, 환자 수: ${patients.length}`);
+
+        // 각 환자별로 개별 작업 생성 (병렬 처리)
+        const jobs = await Promise.all(
+            patients.map(async (patient, index) => {
+                return await healthBatchQueue.add('analyze-patient', {
+                    jobId,
+                    patientId: patient.id,
+                    patientData: patient,
+                    priority: index < 10 ? 1 : 2 // 처음 10명은 높은 우선순위
+                }, {
+                    priority: index < 10 ? 1 : 2
+                });
+            })
+        );
+
+        console.log(`건강검진 배치 분석 작업 ${jobs.length}개가 큐에 추가되었습니다.`);
+
+        return {
+            success: true,
+            jobId,
+            queuedJobs: jobs.length,
+            message: `${jobs.length}개 환자 분석 작업이 큐에 추가되었습니다.`
+        };
+    } catch (error) {
+        logger.error('건강검진 배치 분석 작업 추가 실패:', error);
+        throw error;
+    }
+}
+
 // 보고서 생성 요청 큐에 작업 추가
 export async function enqueueReportGeneration(options = {}, handlerEndpoint) {
     // filepath가 있으면 파일 내용을 우선 사용하고, prompt가 있으면 추가
@@ -464,39 +502,6 @@ export async function enqueueReportGeneration(options = {}, handlerEndpoint) {
     };
 }
 
-// 건강검진 배치 분석 요청 큐에 작업 추가
-export async function enqueueHealthBatchAnalysis(jobId, patients) {
-    try {
-        console.log(`건강검진 배치 분석 큐에 작업 추가: ${jobId}, 환자 수: ${patients.length}`);
-        
-        // 각 환자별로 개별 작업 생성 (병렬 처리)
-        const jobs = await Promise.all(
-            patients.map(async (patient, index) => {
-                return await healthBatchQueue.add('analyze-patient', {
-                    jobId,
-                    patientId: patient.id,
-                    patientData: patient,
-                    priority: index < 10 ? 1 : 2 // 처음 10명은 높은 우선순위
-                }, {
-                    priority: index < 10 ? 1 : 2
-                });
-            })
-        );
-        
-        console.log(`건강검진 배치 분석 작업 ${jobs.length}개가 큐에 추가되었습니다.`);
-        
-        return {
-            success: true,
-            jobId,
-            queuedJobs: jobs.length,
-            message: `${jobs.length}개 환자 분석 작업이 큐에 추가되었습니다.`
-        };
-    } catch (error) {
-        logger.error('건강검진 배치 분석 작업 추가 실패:', error);
-        throw error;
-    }
-}
-
 // API 요청 큐에 작업 추가
 export async function enqueueApiRequest(endpoint, method, params, body, headers, handlerEndpoint, priority = 'normal') {
     try {
