@@ -5,9 +5,9 @@ import './globals.css';
 import type { Metadata } from 'next';
 import { Inter } from 'next/font/google';
 import { initSupportTicketsTable } from '@/app/api/db';
-import Header from '@/components/Header';
 import ThemeProvider from '@/components/ThemeProvider';
 import { LanguageProvider } from '@/contexts/LanguageContext';
+import ConditionalLayout from '@/components/ConditionalLayout';
 
 // Initialize the database table on server start
 initSupportTicketsTable();
@@ -29,16 +29,9 @@ export default function RootLayout({
       <body className={inter.className} suppressHydrationWarning>
         <ThemeProvider>
           <LanguageProvider>
-            <div className="h-screen flex flex-col" style={{ backgroundColor: 'var(--body-bg)' }}>
-              {/* 상단 네비게이션 */}
-              <Header />
-              
-              {/* 메인 콘텐츠 영역 */}
-              <main className="flex-1 overflow-auto min-h-0" style={{ backgroundColor: 'var(--body-bg)' }}>
-                {children}
-              </main>
-              
-            </div>
+            <ConditionalLayout>
+              {children}
+            </ConditionalLayout>
           </LanguageProvider>
         </ThemeProvider>
       </body>
