@@ -541,13 +541,13 @@ export const ChatMarkdownRenderer: React.FC<ChatMarkdownRendererProps> = ({
           <div className="space-y-1">
             {downloadInfo.map((item, index) => {
               // source 필드로 웹과 문서 구분
-              // console.log(`📋 Item ${index}:`, { 
-              //   filename: item.filename, 
-              //   source: item.source, 
-              //   url: item.url,
-              //   pages: item.pages 
-              // });
-              
+              console.log(`📋 [ChatMarkdownRenderer] Item ${index}:`, {
+                filename: item.filename,
+                source: item.source,
+                url: item.url,
+                pages: item.pages
+              });
+
               // source 필드를 기준으로 웹 링크인지 문서인지 판단
               const isWebLink = item.source === 'web';
               
@@ -574,27 +574,40 @@ export const ChatMarkdownRenderer: React.FC<ChatMarkdownRendererProps> = ({
                 // 문서는 다운로드 버튼으로 표시
                 const apiServerUrl = getApiServerUrl();
 
-                // 생성된 문서와 RAG 문서를 구분하여 적절한 다운로드 URL 사용
+                // 다운로드 URL 결정 로직
                 let downloadUrl;
-                const isGeneratedDocument = item.source === 'generated' ||
-                                          item.filename?.includes('petition_') ||
-                                          item.filename?.includes('business_') ||
-                                          item.filename?.includes('license_') ||
-                                          item.url?.includes('/download/');
 
-                if (isGeneratedDocument) {
-                  // 생성된 문서는 /api/v1/download/{filename} 형식 사용
-                  // item.url이 이미 전체 URL이면 사용, 아니면 apiServerUrl 기반으로 구성
-                  if (item.url && (item.url.startsWith('http://') || item.url.startsWith('https://'))) {
+                // 1순위: item.url이 명시적으로 제공된 경우 사용
+                if (item.url) {
+                  if (item.url.startsWith('http://') || item.url.startsWith('https://')) {
+                    // 완전한 URL인 경우 그대로 사용
                     downloadUrl = item.url;
+                  } else if (item.url.startsWith('/api/v1/download/') || item.url.startsWith('/download/')) {
+                    // 상대 경로인 경우 baseUrl과 결합
+                    const baseUrl = apiServerUrl.replace('/api/v1', '');
+                    downloadUrl = `${baseUrl}${item.url}`;
                   } else {
-                    // apiServerUrl에서 /api/v1 부분을 제거하고 /api/v1/download 추가
+                    // 기타 경로 형식
+                    downloadUrl = item.url;
+                  }
+                  console.log('🔗 [ChatMarkdownRenderer] URL from item.url:', downloadUrl);
+                } else {
+                  // 2순위: source와 filename으로 URL 구성
+                  const isGeneratedDocument = item.source === 'generated' ||
+                                            item.filename?.includes('petition_') ||
+                                            item.filename?.includes('business_') ||
+                                            item.filename?.includes('license_');
+
+                  if (isGeneratedDocument) {
+                    // 생성된 문서는 /api/v1/download/{filename} 형식
                     const baseUrl = apiServerUrl.replace('/api/v1', '');
                     downloadUrl = `${baseUrl}/api/v1/download/${encodeURIComponent(item.filename)}`;
+                    console.log('🔗 [ChatMarkdownRenderer] Generated doc URL:', downloadUrl);
+                  } else {
+                    // RAG 문서는 /rag/download?filename= 형식
+                    downloadUrl = `${apiServerUrl}/rag/download?filename=${encodeURIComponent(item.filename)}`;
+                    console.log('🔗 [ChatMarkdownRenderer] RAG doc URL:', downloadUrl);
                   }
-                } else {
-                  // RAG 문서는 기존 /rag/download?filename= 형식 사용
-                  downloadUrl = `${apiServerUrl}/rag/download?filename=${encodeURIComponent(item.filename)}`;
                 }
 
                 return (
