@@ -26,7 +26,8 @@ import {
   ChevronDown,
   Building2,
   Activity,
-  Files
+  Files,
+  FormInput
 } from 'lucide-react';
 
 interface User {
@@ -47,6 +48,7 @@ const getMenuVisibility = () => {
     document: process.env.NEXT_PUBLIC_ENABLE_DOCUMENT === 'true',
     flowai: process.env.NEXT_PUBLIC_ENABLE_FLOWAI === 'true',
     business: process.env.NEXT_PUBLIC_ENABLE_BUSINESS === 'true',
+    formbuilder: process.env.NEXT_PUBLIC_ENABLE_FORMBUILDER === 'true',
     support: process.env.NEXT_PUBLIC_ENABLE_SUPPORT === 'true',
     ragAdmin: process.env.NEXT_PUBLIC_ENABLE_RAG_ADMIN === 'true',
     modelAdmin: process.env.NEXT_PUBLIC_ENABLE_MODEL_ADMIN === 'true',
@@ -91,6 +93,7 @@ export default function Header() {
     { name: t('header.agent', '자동화'), path: '/agent', icon: Bot, section: 'agent', enabled: menuVisibility.agent },
     { name: t('header.assistant', 'Assistant'), path: '/assistant', icon: User, section: 'assistant', enabled: menuVisibility.assistant },
     { name: t('header.document', '문서'), path: '/document', icon: FileText, section: 'document', enabled: menuVisibility.document },
+    { name: t('header.formbuilder', '폼빌더'), path: '/formbuilder', icon: FormInput, section: 'formbuilder', enabled: menuVisibility.formbuilder },
     { name: t('header.business', '사업분석'), path: '/business', icon: Building2, section: 'business', enabled: menuVisibility.business },
     { name: t('header.support', '고객센터'), path: '/support', icon: HelpCircle, section: 'support', enabled: menuVisibility.support }
   ].filter(item => item.enabled);
@@ -102,13 +105,14 @@ export default function Header() {
 
   // 관리자용 추가 메뉴 (환경 변수 기반 필터링)
   const adminNavigationItems = [
-    { name: t('header.rag', 'RAG'), path: '/admin/rag', icon: FolderOpen, section: 'rag', enabled: menuVisibility.ragAdmin },    
+    { name: t('header.rag', 'RAG'), path: '/admin/rag', icon: FolderOpen, section: 'rag', enabled: menuVisibility.ragAdmin },
     { name: t('header.health', '헬스'), path: '/admin/health-batch', icon: Activity, section: 'health-batch', enabled: true },
-    { name: t('header.models', '파인튜닝'), path: '/admin/models', icon: Brain, section: 'models', enabled: menuVisibility.modelAdmin },    
+    { name: t('header.esg', 'ESG'), path: '/admin/esg-analysis', icon: Files, section: 'esg-analysis', enabled: true },
+    { name: t('header.models', '파인튜닝'), path: '/admin/models', icon: Brain, section: 'models', enabled: menuVisibility.modelAdmin },
     { name: t('header.evaluation', '평가'), path: '/admin/evaluation', icon: TrendingUp, section: 'evaluation', enabled: menuVisibility.evaluation },
-    { name: t('header.users', '사용자'), path: '/admin/users', icon: Users, section: 'users', enabled: menuVisibility.userAdmin },    
+    { name: t('header.users', '사용자'), path: '/admin/users', icon: Users, section: 'users', enabled: menuVisibility.userAdmin },
     { name: t('header.settings', '설정'), path: '/settings', icon: Settings, section: 'settings', enabled: menuVisibility.settings },
-    { name: t('header.monitoring', '모니터링'), path: '/monitoring', icon: BarChart3, section: 'monitoring', enabled: menuVisibility.monitoring }   
+    { name: t('header.monitoring', '모니터링'), path: '/monitoring', icon: BarChart3, section: 'monitoring', enabled: menuVisibility.monitoring }
   ].filter(item => item.enabled);
 
   // 매니저용 메뉴 (환경 변수 기반 필터링)
